#!/usr/bin/ruby

def gps_to_deg(gps_coord)
  gps_coord.match(/^([0-9]+)([0-9]{2}.[0-9]+)$/)
  return $1.to_f + $2.to_f / 60
end

def get_position
  File.open('/dev/tty.BTGPS-SPPSlave-1', 'r') do |f|
    while line = f.gets
      if line.match(/^\$GPRMC,.*?,.*?,(.*?),N,(.*?),E/)
        lat = gps_to_deg($1)
        lon = gps_to_deg($2)
        return [lat, lon]
      end
    end
  end
end

# record a wav file
# file is not a complete filename
# duration is only approximate
def record(file, duration)
  # file is not a real filename
  system("osascript tools/record.scpt #{file} #{duration}")
end

log_filename = 'messungen/list.csv'

if File.exist?(log_filename)
  puts "warning: logfile already exists. press enter to continue (new data will be appended)"
  gets
end
  

i = 0
while true
  i = i + 1
  
  if File.exist?("messungen/#{i}.wav")
    puts "file #{i} already exists. skipping"
    next
  end
  
  puts "press enter to start recording (optional: enter a comment)"
  comment = gets
  puts "getting position..."
  pos = get_position
  puts "done."
  time = Time.now.to_i
  puts "logging..."
  File.open(log_filename, 'a+') do |f|
    s = "#{i},#{pos[0]},#{pos[1]},#{time},#{comment}"
    f.puts s
    puts s
  end
  puts "done."
  puts "recording..."
  record(i, 10)
  puts "done."
  puts "testing..."
  system("octave -q --eval 'inputfile=\"messungen/#{i}.wav\"; decoder'")
  puts "done."
end
