#include "m-seq.h"

/*
// Generate a maximum length sequence (m-sequence) with an 8 bit shift register.
// sequence length: 254; taps (7,1,0) are taken from "Numeriacl Recipes in C" p. 299
uint8_t seq_bit()
{
  uint8_t bit;
  static uint8_t state = 1;

  // calculate a bit from
  bit = ((state >> 7) & 1)
      ^ ((state >> 1) & 1)
      ^ ((state >> 0) & 1);
  
  // shift register left, put the result of the XORs in bit 1
  state = (state << 1) | bit;

  return bit;
}
*/


static uint16_t state = 1;

void seq_reset(void)
{
  state = 1;
}

// Generate a maximum length sequence (m-sequence) with a 16 bit shift register.
// sequence length: 2^N - 1; taps (7,1,0) are taken from "Numeriacl Recipes in C" p. 299
uint8_t seq_bit()
{
  uint8_t bit;

  // calculate a bit from
  bit = ((state >> 15) & 1)
      ^ ((state >> 1) & 1)
      ^ ((state >> 0) & 1);
  
  // shift register left, put the result of the XORs in bit 1
  state = (state << 1) | bit;

  return bit;
}
